# libraries
library(lmerTest)
library(MuMIn)
library(dplyr)
library(stringr)

# set wd
setwd("Drive/folderpath/")


# Function ----------------------------------------------------------------

response.f <- function(mod, indicator, land_use, variable){
  fe.df <- as.data.frame(fixef(mod))
  fe.df <- mutate(fe.df, p = as.data.frame(summary(mod)$coefficients)[, ncol(as.data.frame(summary(mod)$coefficients))])
  fe.df <- mutate(fe.df, FE_level = row.names(fe.df))
  fe.df <- rename(fe.df, Effect_size = 1)
  fe.df <- select(fe.df, FE_level, Effect_size, p)
  ci.df <- tail(confint(mod, method = "boot", nsim = 1000), nrow(fe.df))
  fe.df <- bind_cols(fe.df, ci.df)
  fe.df <- rename(fe.df, Effect_size_lwr = `2.5 %`, Effect_size_upr = `97.5 %`)
  if(indicator == "MSA"){
    fe.df <- mutate(fe.df, Response = exp(Effect_size) / (1 + exp(Effect_size)),
                    Response_lwr = exp(Effect_size_lwr) / (1 + exp(Effect_size_lwr)),
                    Response_upr = exp(Effect_size_upr) / (1 + exp(Effect_size_upr)))
  } else{
    fe.df <- mutate(fe.df, Response = exp(Effect_size),
                    Response_lwr = exp(Effect_size_lwr),
                    Response_upr = exp(Effect_size_upr))
  }
  fe.df <- mutate(fe.df, Indicator = indicator, Land_use = land_use, Variable = variable)
  fe.df <- select(fe.df, Indicator:Variable, FE_level:Response_upr)
  row.names(fe.df) <- NULL
  fe.df <- mutate(fe.df, FE_level = str_replace(FE_level, "Natural_elements", ""))
  fe.df <- mutate(fe.df, FE_level = str_replace(FE_level, "Diversification", ""))
  fe.df <- mutate(fe.df, FE_level = str_replace(FE_level, "(Intercept)", "Overall effect"))
  fe.df <- mutate(fe.df, FE_level = str_replace_all(FE_level, "_", " "))
  fe.df
}


# Read data ---------------------------------------------------------------

dat.df <- read.csv("./Data_derived/RIA_RSR_effect_sizes.csv")
msa.df <- read.csv("./Data_derived/MSA_effect_sizes.csv")
sp.df <- read.csv("./Data_raw/Species_data.csv")
lc.df <- read.csv("./Data_raw/Landscape_data.csv")

dat.df <- filter(dat.df, Land_use %in% c("Cropland", "Forest_plantation"), !is.na(Natural_elements), !is.na(Diversification))
dat.df <- mutate(dat.df, Year = coalesce(Data_collection_end_yr, Reference_yr))
dat.df <- mutate(dat.df, Natural_elements = str_replace(Natural_elements, "Inclusion", "With"))
dat.df <- mutate(dat.df, Natural_elements = str_replace(Natural_elements, "Exclusion", "Without"))
dat.df$Diversification[dat.df$Land_use == "Forest_plantation"] <- str_replace(dat.df$Diversification[dat.df$Land_use == "Forest_plantation"], "crop", "tree")
dat.df$Diversification[dat.df$Land_use == "Forest_plantation"] <- str_replace(dat.df$Diversification[dat.df$Land_use == "Forest_plantation"], "Crop", "Tree")

ria.df <- filter(dat.df, Diversity_metric_type == "Abundance")
ria.df <- left_join(ria.df, sp.df)
ria.df <- mutate(ria.df, Body_mass = log(Body_mass), Latitude_abs = abs(Latitude), Latitude2_abs = abs(Latitude)^2)
ria.df <- left_join(ria.df, dplyr::select(lc.df, -ID))
ria.df <- filter(ria.df, !is.na(Habitat_breadth), !is.na(Origin), !is.na(Diet_diversity), !is.na(Body_mass))
ria.df <- mutate(ria.df, Indicator = "Species\nabundance")

rsr.df <- filter(dat.df, Diversity_metric_type == "Richness")
rsr.df <- left_join(rsr.df, dplyr::select(lc.df, -ID))
rsr.df <- mutate(rsr.df, Latitude_abs = abs(Latitude), Latitude2_abs = abs(Latitude)^2)
rsr.df <- mutate(rsr.df, Indicator = "Species\nrichness")

msa.df <- filter(msa.df, Land_use %in% c("Cropland", "Forest_plantation"))
msa.df <- mutate(msa.df, ltMSA = log(MSA_site / (1 - MSA_site)),
                 Year = coalesce(Data_collection_end_yr, Reference_yr),
                 Latitude_abs = abs(Latitude), Latitude2_abs = abs(Latitude)^2)
msa.df <- left_join(msa.df, select(lc.df, -ID))
msa.df <- mutate(msa.df, Natural_elements = str_replace(Natural_elements, "Inclusion", "With"))
msa.df <- mutate(msa.df, Natural_elements = str_replace(Natural_elements, "Exclusion", "Without"))
msa.df$Diversification[msa.df$Land_use == "Forest_plantation"] <- str_replace(msa.df$Diversification[msa.df$Land_use == "Forest_plantation"], "crop", "tree")
msa.df$Diversification[msa.df$Land_use == "Forest_plantation"] <- str_replace(msa.df$Diversification[msa.df$Land_use == "Forest_plantation"], "Crop", "Tree")
msa.df <- mutate(msa.df, Indicator = "Assemblage\nintactness")

rm(dat.df, sp.df, lc.df)


# Abundance ---------------------------------------------------------------

# Cropland
ria_c.df <- filter(ria.df, Land_use == "Cropland")

## Main
ria_cm.lm <- lmer(lnRR ~ -1 + Natural_elements + (1|Source_ID / Study_ID), weights = weight, data = ria_c.df, REML = T)
ria_cm.df <- response.f(ria_cm.lm, "RIA", "Cropland", "Overall effects")

## Habitat diversity
ria_ch.lm <- lmer(lnRR ~ -1 + Natural_elements + Habitat_breadth + (1|Source_ID / Study_ID), weights = weight, data = ria_c.df, REML = T)
ria_ch.df <- response.f(ria_ch.lm, "RIA", "Cropland", "Habitat diversity")

# Forest plantation
ria_f.df <- filter(ria.df, Land_use == "Forest_plantation")

## Main
ria_fm.lm <- lmer(lnRR ~ 1 + (1|Source_ID / Study_ID), weights = weight, data = ria_f.df, REML = T)
ria_fm.df <- response.f(ria_fm.lm, "RIA", "Forest plantation", "Overall effect")

## Habitat diversity
ria_fh.lm <- lmer(lnRR ~ Habitat_breadth + (1|Source_ID / Study_ID), weights = weight, data = ria_f.df, REML = T)
ria_fh.df <- response.f(ria_fh.lm, "RIA", "Forest plantation", "Overall effect")


# Richness ----------------------------------------------------------------

# Cropland
rsr_c.df <- filter(rsr.df, Land_use == "Cropland")

## Main
rsr_cm.lm <- lmer(lnRR ~ -1 + Natural_elements + (1|Source_ID / Study_ID), weights = weight, REML = T, data = rsr_c.df)
rsr_cm.df <- response.f(rsr_cm.lm, "RSR", "Cropland", "Overall effects")

# Forest plantation
rsr_f.df <- filter(rsr.df, Land_use == "Forest_plantation")

## Main
rsr_fm.lm <- lmer(lnRR ~ -1 + Natural_elements + (1|Source_ID / Study_ID), weights = weight, REML = T, data = rsr_f.df)
rsr_fm.df <- response.f(rsr_fm.lm, "RSR", "Forest plantation", "Overall effects")

## Latitude
rsr_fl.lm <- lmer(lnRR ~ -1 + Natural_elements + Latitude_abs + (1|Source_ID / Study_ID), weights = weight, REML = T, data = rsr_f.df)
rsr_fl.df <- response.f(rsr_fl.lm, "RSR", "Forest plantation", "Latitude")


# MSA ---------------------------------------------------------------------

# Cropland
msa_c.df <- filter(msa.df, Land_use == "Cropland")

## Main
msa_cm.lm <- lmer(ltMSA ~ -1 + Natural_elements + (1|Source_ID / Study_ID), weights = weight, data = msa_c.df, REML = T)
msa_cm.df <- response.f(msa_cm.lm, "MSA", "Cropland", "Overall effect")

## Absolute latitude
msa_cl.lm <- lmer(ltMSA ~ -1 + Natural_elements + Latitude_abs + Latitude2_abs + (1|Source_ID / Study_ID), weights = weight, data = msa_c.df, REML = T)
msa_cl.df <- response.f(msa_cl.lm, "MSA", "Cropland", "Latitude")

# Forest plantation
msa_f.df <- filter(msa.df, Land_use == "Forest_plantation")

## Main
msa_fm.lm <- lmer(ltMSA ~ -1 + Diversification + (1|Source_ID / Study_ID), weights = weight, data = msa_f.df, REML = T)
msa_fm.df <- response.f(msa_fm.lm, "MSA", "Forest plantation", "Overall effect")

## Landscape context
msa_flc.lm <- lmer(ltMSA ~ -1 + Diversification + Landscape_context + (1|Source_ID / Study_ID), weights = weight, data = msa_f.df, REML = T)
msa_flc.df <- response.f(msa_flc.lm, "MSA", "Forest plantation", "Landscape context")


# Combine -----------------------------------------------------------------

all.df <- bind_rows(ria_cm.df, ria_ch.df, ria_fm.df, ria_fh.df,
                    rsr_cm.df, rsr_fm.df, rsr_fl.df,
                    msa_cm.df, msa_cl.df, msa_fm.df, msa_flc.df)
all.df <- mutate(all.df, Effect_size = round(Effect_size, 2), p = round(p, 3))
all.df <- mutate_at(all.df, colnames(select(all.df, Effect_size_lwr:Response_upr)), function(x){round(x, 2)})
all.df <- mutate(all.df, 
                  Indicator = str_replace(Indicator, "RIA", "lnRIA"),
                  Indicator = str_replace(Indicator, "MSA", "logitMSA"),
                  Indicator = str_replace(Indicator, "RSR", "lnRSR"),
                  `Estimate (95% CI)` = paste0(Effect_size, " (", Effect_size_lwr, ", ", Effect_size_upr, ")"),
                  `Back-transformed estimate (95% CI)` = paste0(Response, " (", Response_lwr, ", ", Response_upr, ")"))
all.df <- select(all.df, Indicator:FE_level, p, `Estimate (95% CI)`, `Back-transformed estimate (95% CI)`)

write.csv(all.df, "./Data_output/Response_estimation.csv", row.names = F)