# libraries
library(sf)
library(lmerTest)
library(MuMIn)
library(dplyr)
library(stringr)
library(ggplot2)
library(forcats)
library(egg)
library(spData)

# set wd
setwd("Drive/folderpath/")

# global variables
col.v <- c("#009E73", "#56B4E9", "#E69F00", "#CC79A7", "#0072B2")
seq.n <- 1000


# Read data ---------------------------------------------------------------

dat.df <- read.csv("./Data_derived/RIA_RSR_effect_sizes.csv")
msa.df <- read.csv("./Data_derived/MSA_effect_sizes.csv")
sp.df <- read.csv("./Data_raw/Species_data.csv")
lc.df <- read.csv("./Data_raw/Landscape_data.csv")

dat.df <- filter(dat.df, Land_use %in% c("Cropland", "Forest_plantation"), !is.na(Natural_elements), !is.na(Diversification))
dat.df <- mutate(dat.df, Year = coalesce(Data_collection_end_yr, Reference_yr))
dat.df <- mutate(dat.df, Natural_elements = str_replace(Natural_elements, "Inclusion", "With"))
dat.df <- mutate(dat.df, Natural_elements = str_replace(Natural_elements, "Exclusion", "Without"))
dat.df$Diversification[dat.df$Land_use == "Forest_plantation"] <- str_replace(dat.df$Diversification[dat.df$Land_use == "Forest_plantation"], "crop", "tree")
dat.df$Diversification[dat.df$Land_use == "Forest_plantation"] <- str_replace(dat.df$Diversification[dat.df$Land_use == "Forest_plantation"], "Crop", "Tree")

ria.df <- filter(dat.df, Diversity_metric_type == "Abundance")
ria.df <- left_join(ria.df, sp.df)
ria.df <- mutate(ria.df, Body_mass = log(Body_mass), Latitude_abs = abs(Latitude), Latitude2_abs = abs(Latitude)^2)
ria.df <- left_join(ria.df, dplyr::select(lc.df, -ID))
ria.df <- filter(ria.df, !is.na(Habitat_breadth), !is.na(Origin), !is.na(Diet_diversity), !is.na(Body_mass))
ria.df <- mutate(ria.df, Indicator = "Individual\nspecies\nabundance")

rsr.df <- filter(dat.df, Diversity_metric_type == "Richness")
rsr.df <- left_join(rsr.df, dplyr::select(lc.df, -ID))
rsr.df <- mutate(rsr.df, Latitude_abs = abs(Latitude), Latitude2_abs = abs(Latitude)^2)
rsr.df <- mutate(rsr.df, Indicator = "Species\nrichness")

msa.df <- filter(msa.df, Land_use %in% c("Cropland", "Forest_plantation"))
msa.df <- mutate(msa.df, ltMSA = log(MSA_site / (1 - MSA_site)),
                 Year = coalesce(Data_collection_end_yr, Reference_yr),
                 Latitude_abs = abs(Latitude), Latitude2_abs = abs(Latitude)^2)
msa.df <- left_join(msa.df, select(lc.df, -ID))
msa.df <- mutate(msa.df, Natural_elements = str_replace(Natural_elements, "Inclusion", "With"))
msa.df <- mutate(msa.df, Natural_elements = str_replace(Natural_elements, "Exclusion", "Without"))
msa.df$Diversification[msa.df$Land_use == "Forest_plantation"] <- str_replace(msa.df$Diversification[msa.df$Land_use == "Forest_plantation"], "crop", "tree")
msa.df$Diversification[msa.df$Land_use == "Forest_plantation"] <- str_replace(msa.df$Diversification[msa.df$Land_use == "Forest_plantation"], "Crop", "Tree")
msa.df <- mutate(msa.df, Indicator = "Assemblage\nintactness")

rm(dat.df, sp.df, lc.df)


# Fig1 Data ---------------------------------------------------------------

# Prepare data
ctr.sf <- spData::world

n.df <- data.frame(Indicator = rep(c("Individual\nspecies\nabundance", "Species\nrichness", "Assemblage\nintactness"), each = 2), 
                   Land_use = rep(c("Cropland", "Forest plantation"), 3),
                   n = c(nrow(filter(ria.df, Land_use == "Cropland")),
                         nrow(filter(ria.df, Land_use == "Forest_plantation")),
                         nrow(filter(rsr.df, Land_use == "Cropland")),
                         nrow(filter(rsr.df, Land_use == "Forest_plantation")),
                         nrow(filter(msa.df, Land_use == "Cropland")),
                         nrow(filter(msa.df, Land_use == "Forest_plantation"))))
n.df <- mutate(n.df, Indicator = as_factor(Indicator), Label = paste0("n = ", n))
dat.df <- bind_rows(distinct(select(ria.df, Longitude, Latitude, Source_ID, Indicator, Land_use)),
                    distinct(select(rsr.df, Longitude, Latitude, Source_ID, Indicator, Land_use)),
                    distinct(select(msa.df, Longitude, Latitude, Source_ID, Indicator, Land_use)))
dat.df <- mutate(dat.df, Land_use = str_replace_all(Land_use, "_", " "), Indicator = as_factor(Indicator))
dat.df <- mutate(dat.df, Indicator = fct_relevel(Indicator, levels(pull(dat.df, Indicator))[c(1, 2, 3)]))
dat.df <- left_join(dat.df, n.df)
dat.sf <- st_as_sf(dat.df, coords = c("Longitude", "Latitude"), dim = "XYZ", remove = F)
rm(dat.df)
st_crs(dat.sf) <- st_crs(4326)

# Figure
ggplot(data = dat.sf) +
  geom_sf(data = ctr.sf, fill = "lightgrey", color = NA) +
  geom_sf(colour = "#0072B2", fill = "#0072B2", size = 1.5, stroke = 0, shape = 21, alpha = 0.5) +
  facet_grid(Indicator ~ Land_use, switch = "y") +
  geom_text(aes(label = Label), x = 0, y = -55, size = 2.7) +
  theme(panel.background = element_blank(),
        legend.title = element_blank(),
        legend.background = element_blank(),
        legend.key = element_blank(),
        legend.position = c(0.14, 0.8),
        strip.background = element_blank(),
        text = element_text(size = 10),
        axis.text = element_blank(),
        axis.ticks = element_blank()
  )

# Fig2 Abundance ----------------------------------------------------------

# Data preparation
## Cropland
ria_c.df <- filter(ria.df, Land_use == "Cropland")
ria_c.df <- group_by(ria_c.df, Natural_elements)
ria_c.df <- mutate(ria_c.df, n = n(), Level = paste0("n = ", n()))
ria_c.df <- ungroup(ria_c.df)
ria_c.df <- mutate(ria_c.df, Natural_elements = as_factor(str_replace_all(Natural_elements, "_", " ")))
ria_c.df <- mutate(ria_c.df, Natural_elements = fct_relevel(Natural_elements, levels(pull(ria_c.df, Natural_elements))[2]))

### (a) Main
ria_c_m.lm <- lmer(lnRR ~ Natural_elements + (1|Source_ID / Study_ID), weights = weight, data = ria_c.df, REML = T)
ria_c_m.df <- distinct(select(ria_c.df, Natural_elements, Level))
b.bm <- bootMer(ria_c_m.lm, nsim = 1000, FUN = function(x){predict(x, newdata = ria_c_m.df, re.form = NA)})
ria_c_m.df <- mutate(ria_c_m.df, lnRR_pred = predict(ria_c_m.lm, newdata = ria_c_m.df, re.form = NA),
                    lnRR_lwr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.025)}),
                    lnRR_upr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.975)}))

### (b) Habitat breadth
ria_c_h.lm <- lmer(lnRR ~ Natural_elements + Habitat_breadth + (1|Source_ID / Study_ID), weights = weight, data = ria_c.df, REML = T)
ria_c_h.df <- distinct(select(ria_c.df, Natural_elements, Level))
ria_c_h.df <- ria_c_h.df[rep(1:nrow(ria_c_h.df), each = seq.n), ]
ria_c_h.df <- mutate(ria_c_h.df, Habitat_breadth = c(seq(min(pull(filter(ria_c.df, Natural_elements == unique(pull(ria_c_h.df, Natural_elements))[1]), Habitat_breadth)),
                                                         max(pull(filter(ria_c.df, Natural_elements == unique(pull(ria_c_h.df, Natural_elements))[1]), Habitat_breadth)),
                                                         (max(pull(filter(ria_c.df, Natural_elements == unique(pull(ria_c_h.df, Natural_elements))[1]), Habitat_breadth)) -
                                                            min(pull(filter(ria_c.df, Natural_elements == unique(pull(ria_c_h.df, Natural_elements))[1]), Habitat_breadth))) /
                                                           (seq.n - 1)),
                                                     seq(min(pull(filter(ria_c.df, Natural_elements == unique(pull(ria_c_h.df, Natural_elements))[2]), Habitat_breadth)),
                                                         max(pull(filter(ria_c.df, Natural_elements == unique(pull(ria_c_h.df, Natural_elements))[2]), Habitat_breadth)),
                                                         (max(pull(filter(ria_c.df, Natural_elements == unique(pull(ria_c_h.df, Natural_elements))[2]), Habitat_breadth)) -
                                                            min(pull(filter(ria_c.df, Natural_elements == unique(pull(ria_c_h.df, Natural_elements))[2]), Habitat_breadth))) /
                                                           (seq.n - 1))
))
b.bm <- bootMer(ria_c_h.lm, nsim = 1000, FUN = function(x){predict(x, newdata = ria_c_h.df, re.form = NA)})
ria_c_h.df <- mutate(ria_c_h.df, lnRR_pred = predict(ria_c_h.lm, newdata = ria_c_h.df, re.form = NA),
                    lnRR_lwr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.025)}),
                    lnRR_upr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.975)}))

## Forest plantations
ria_f.df <- filter(ria.df, Land_use == "Forest_plantation")
ria_f.df <- mutate(ria_f.df, Level = paste0("n = ", n()))

### Main
ria_f_m.lm <- lmer(lnRR ~ 1 + (1|Source_ID / Study_ID), weights = weight, data = ria_f.df, REML = T)
ria_f_m.df <- distinct(select(ria_f.df, Level))
b.bm <- bootMer(ria_f_m.lm, nsim = 1000, FUN = function(x){predict(x, newdata = ria_f_m.df, re.form = NA)})
ria_f_m.df <- mutate(ria_f_m.df, lnRR_pred = predict(ria_f_m.lm, newdata = ria_f_m.df, re.form = NA),
                    lnRR_lwr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.025)}),
                    lnRR_upr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.975)}))

### Habitat breadth
ria_f_h.lm <- lmer(lnRR ~ Habitat_breadth + (1|Source_ID / Study_ID), weights = weight, data = ria_f.df, REML = T)
ria_f_h.df <- distinct(select(ria_f.df, Level))
ria_f_h.df <- as.data.frame(ria_f_h.df[rep(1:nrow(ria_f_h.df), each = seq.n), ])
ria_f_h.df <- mutate(ria_f_h.df, Habitat_breadth = seq(min(pull(ria_f.df, Habitat_breadth)),
                                                       max(pull(ria_f.df, Habitat_breadth)),
                                                       (max(pull(ria_f.df, Habitat_breadth)) -
                                                          min(pull(ria_f.df, Habitat_breadth))) /
                                                         (seq.n - 1)))
b.bm <- bootMer(ria_f_h.lm, nsim = 1000, FUN = function(x){predict(x, newdata = ria_f_h.df, re.form = NA)})
ria_f_h.df <- mutate(ria_f_h.df, lnRR_pred = predict(ria_f_h.lm, newdata = ria_f_h.df, re.form = NA),
                    lnRR_lwr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.025)}),
                    lnRR_upr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.975)}))

## min and max values
ria_mn.n <- min(c(pull(ria_c_m.df, lnRR_lwr),
                  pull(ria_c_h.df, lnRR_lwr),
                  pull(ria_f_m.df, lnRR_lwr),
                  pull(ria_f_h.df, lnRR_lwr)))
ria_mx.n <- max(c(pull(ria_c_m.df, lnRR_upr),
                  pull(ria_c_h.df, lnRR_upr),
                  pull(ria_f_m.df, lnRR_upr),
                  pull(ria_f_h.df, lnRR_upr)))
hab_mn.n <- min(c(pull(ria_c_h.df, Habitat_breadth),
                  pull(ria_f_h.df, Habitat_breadth)))
hab_mx.n <- max(c(pull(ria_c_h.df, Habitat_breadth),
                  pull(ria_f_h.df, Habitat_breadth)))

# Figures
## Cropland
### (a) Main
f2a1 <- ggplot(data = ria_c_m.df, aes(y = lnRR_pred, x = Level, col = Natural_elements, fill = Natural_elements)) +
  #rphylopic::add_phylopic(x = 1, y = 1, uuid = "cd2aa8d4-a965-44dc-875f-bbc658813f30", ysize = 0.5) +
  geom_hline(yintercept = 0, linetype = "dashed") +
  geom_pointrange(aes(ymin = lnRR_lwr, ymax = lnRR_upr), size = 0.6, linewidth = 0.8) +
  scale_colour_manual(values = col.v[c(1, 3)]) +
  ylab("lnRIA") +
  ggtitle("(a)") +
  coord_cartesian(ylim = c(ria_mn.n,
                           ria_mx.n)) +
  theme(panel.background = element_blank(),
        panel.grid = element_blank(),
        axis.line = element_line(),
        axis.text = element_text(colour = "black", size = 10),
        axis.title.x = element_blank(),
        axis.title.y = element_text(size = 10),
        plot.title = element_text(size = 10, face = "bold", hjust = 0),
        plot.subtitle = element_text(size = 10, hjust = 0.5, vjust = 0),
        legend.text = element_text(colour = "black", size = 10),
        legend.title = element_blank(),
        legend.position = c(0, 1.1),
        legend.justification = c("left", "top"),
        legend.background = element_blank(),
        legend.key = element_blank())

### (b) Habitat diversity
f2a2 <- ggplot(data = ria_c_h.df, aes(y = lnRR_pred, x = Habitat_breadth, col = Natural_elements, fill = Natural_elements)) +
  geom_hline(yintercept = 0, linetype = "dashed") +
  geom_line(linewidth = 1.5) +
  geom_ribbon(aes(ymin = lnRR_lwr, ymax = lnRR_upr), alpha = 0.2, col = NA) +
  scale_x_continuous(breaks = seq(1, max(ria_c.df$Habitat_breadth, na.rm = T), 2)) +
  scale_colour_manual(values = col.v[c(1, 3)]) +
  scale_fill_manual(values = col.v[c(1, 3)]) +
  ylab("lnRIA") +
  xlab("Habitat breadth") +
  #ggtitle("(b)") +
  coord_cartesian(ylim = c(ria_mn.n,
                           ria_mx.n),
                  xlim = c(hab_mn.n,
                           hab_mx.n)) +
  theme(panel.background = element_blank(),
        panel.grid = element_blank(),
        axis.line = element_line(),
        axis.text = element_text(colour = "black", size = 10),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.title.x = element_text(size = 10),
        plot.title = element_text(size = 10, face = "bold", hjust = 0),
        legend.title = element_blank(),
        legend.position = "none",
        legend.direction = "vertical",
        legend.justification = c("left", "top"),
        legend.background = element_blank(),
        legend.key = element_blank())

## Forest plantations
### Main
f2b1 <- ggplot(data = ria_f_m.df, aes(y = lnRR_pred, x = Level)) +
  #rphylopic::add_phylopic(x = -1, y = 2, name = "Pinus", ysize = 1) +
  geom_hline(yintercept = 0, linetype = "dashed") +
  geom_pointrange(aes(ymin = lnRR_lwr, ymax = lnRR_upr), size = 0.6, linewidth = 0.8, colour = col.v[5]) +
  scale_colour_manual(values = col.v[5]) +
  ylab("lnRIA") +
  ggtitle("(b)") +
  coord_cartesian(ylim = c(ria_mn.n,
                           ria_mx.n)) +
  theme(panel.background = element_blank(),
        panel.grid = element_blank(),
        axis.line = element_line(),
        axis.text = element_text(colour = "black", size = 10),
        axis.title.x = element_blank(),
        axis.title.y = element_text(size = 10),
        plot.title = element_text(size = 10, face = "bold", hjust = 0),
        plot.subtitle = element_text(size = 10, hjust = 0.5, vjust = 0),
        legend.title = element_blank(),
        legend.position = c(0, 1.1),
        legend.justification = c("left", "top"),
        legend.background = element_blank(),
        legend.key = element_blank())

### Habitat breadth
f2b2 <- ggplot(data = ria_f_h.df, aes(y = lnRR_pred, x = Habitat_breadth)) +
  geom_hline(yintercept = 0, linetype = "dashed") +
  geom_line(linewidth = 1.5, colour = col.v[5]) +
  geom_ribbon(aes(ymin = lnRR_lwr, ymax = lnRR_upr), alpha = 0.2, col = NA, fill = col.v[5]) +
  scale_x_continuous(breaks = seq(1, max(ria_c.df$Habitat_breadth, na.rm = T), 2)) +
  #scale_colour_manual(values = col.v[c(1, 3)]) +
  #scale_fill_manual(values = col.v[c(1, 3)]) +
  ylab("lnRIA") +
  xlab("Habitat breadth") +
  #ggtitle("(d)") +
  coord_cartesian(ylim = c(ria_mn.n,
                           ria_mx.n),
                  xlim = c(hab_mn.n,
                           hab_mx.n)) +
  theme(panel.background = element_blank(),
        panel.grid = element_blank(),
        axis.line = element_line(),
        axis.text = element_text(colour = "black", size = 10),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.title.x = element_text(size = 10),
        plot.title = element_text(size = 10, face = "bold", hjust = 0),
        legend.title = element_blank(),
        legend.text = element_text(colour = "black", size = 10),
        legend.position = "none",
        legend.direction = "vertical",
        legend.justification = c("left", "top"),
        legend.background = element_blank(),
        legend.key = element_blank())

## Panels
ggarrange(f2a1, f2a2, f2b1, f2b2, ncol = 2)


# Fig4 Richness -----------------------------------------------------------

# Prepare data
## Cropland
rsr_c.df <- filter(rsr.df, Land_use == "Cropland")
rsr_c.df <- group_by(rsr_c.df, Natural_elements)
rsr_c.df <- mutate(rsr_c.df, n = n(), Level = paste0("n = ", n()))
rsr_c.df <- ungroup(rsr_c.df)
rsr_c.df <- mutate(rsr_c.df, Natural_elements = as_factor(str_replace_all(Natural_elements, "_", " ")))
rsr_c.df <- mutate(rsr_c.df, Natural_elements = fct_relevel(Natural_elements, levels(pull(rsr_c.df, Natural_elements))[2]))

### Main
rsr_c_m.lm <- lmer(lnRR ~ Natural_elements + (1|Source_ID / Study_ID), weights = weight, data = rsr_c.df, REML = T)
rsr_c_m.df <- distinct(select(rsr_c.df, Natural_elements, Level))
b.bm <- bootMer(rsr_c_m.lm, nsim = 1000, FUN = function(x){predict(x, newdata = rsr_c_m.df, re.form = NA)})
rsr_c_m.df <- mutate(rsr_c_m.df, lnRR_pred = predict(rsr_c_m.lm, newdata = rsr_c_m.df, re.form = NA),
                   lnRR_lwr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.025)}),
                   lnRR_upr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.975)}))

## Forest plantation
rsr_f.df <- filter(rsr.df, Land_use == "Forest_plantation")
rsr_f.df <- group_by(rsr_f.df, Natural_elements)
rsr_f.df <- mutate(rsr_f.df, n = n(), Level = paste0("n = ", n()))
rsr_f.df <- ungroup(rsr_f.df)
rsr_f.df <- mutate(rsr_f.df, Natural_elements = as_factor(str_replace_all(Natural_elements, "_", " ")))
rsr_f.df <- mutate(rsr_f.df, Natural_elements = fct_relevel(Natural_elements, levels(pull(rsr_f.df, Natural_elements))[2]))

### Main
rsr_f_m.lm <- lmer(lnRR ~ Natural_elements + (1|Source_ID / Study_ID), weights = weight, data = rsr_f.df, REML = T)
rsr_f_m.df <- distinct(select(rsr_f.df, Natural_elements, Level))
b.bm <- bootMer(rsr_f_m.lm, nsim = 1000, FUN = function(x){predict(x, newdata = rsr_f_m.df, re.form = NA)})
rsr_f_m.df <- mutate(rsr_f_m.df, lnRR_pred = predict(rsr_f_m.lm, newdata = rsr_f_m.df, re.form = NA),
                   lnRR_lwr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.025)}),
                   lnRR_upr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.975)}))

### Latitude
rsr_f_l.lm <- lmer(lnRR ~ Natural_elements + Latitude_abs + (1|Source_ID / Study_ID), weights = weight, data = rsr_f.df, REML = T)
rsr_f_l.df <- distinct(select(rsr_f.df, Natural_elements, Level))
rsr_f_l.df <- rsr_f_l.df[rep(1:nrow(rsr_f_l.df), each = seq.n), ]
rsr_f_l.df <- mutate(ria_c_h.df, Latitude_abs = c(seq(min(pull(filter(rsr_f.df, Natural_elements == unique(pull(rsr_f_l.df, Natural_elements))[1]), Latitude_abs)),
                                                    max(pull(filter(rsr_f.df, Natural_elements == unique(pull(rsr_f_l.df, Natural_elements))[1]), Latitude_abs)),
                                                    (max(pull(filter(rsr_f.df, Natural_elements == unique(pull(rsr_f_l.df, Natural_elements))[1]), Latitude_abs)) -
                                                       min(pull(filter(rsr_f.df, Natural_elements == unique(pull(rsr_f_l.df, Natural_elements))[1]), Latitude_abs))) /
                                                      (seq.n - 1)),
                                                seq(min(pull(filter(rsr_f.df, Natural_elements == unique(pull(rsr_f_l.df, Natural_elements))[2]), Latitude_abs)),
                                                    max(pull(filter(rsr_f.df, Natural_elements == unique(pull(rsr_f_l.df, Natural_elements))[2]), Latitude_abs)),
                                                    (max(pull(filter(rsr_f.df, Natural_elements == unique(pull(rsr_f_l.df, Natural_elements))[2]), Latitude_abs)) -
                                                       min(pull(filter(rsr_f.df, Natural_elements == unique(pull(rsr_f_l.df, Natural_elements))[2]), Latitude_abs))) /
                                                      (seq.n - 1))
))
b.bm <- bootMer(rsr_f_l.lm, nsim = 1000, FUN = function(x){predict(x, newdata = rsr_f_l.df, re.form = NA)})
rsr_f_l.df <- mutate(rsr_f_l.df, lnRR_pred = predict(rsr_f_l.lm, newdata = rsr_f_l.df, re.form = NA),
                   lnRR_lwr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.025)}),
                   lnRR_upr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.975)}))

## Min and max values
rsr_mn.n <- min(c(pull(rsr_c_m.df, lnRR_lwr), pull(rsr_f_m.df, lnRR_lwr), pull(rsr_f_l.df, lnRR_lwr)))
rsr_mx.n <- max(c(pull(rsr_c_m.df, lnRR_upr), pull(rsr_f_m.df, lnRR_upr), pull(rsr_f_l.df, lnRR_upr)))

# Figures
## Cropland
### (a) Main
f3a <- ggplot(data = rsr_c_m.df, aes(y = lnRR_pred, x = Level, col = Natural_elements, fill = Natural_elements)) +
  geom_hline(yintercept = 0, linetype = "dashed") +
  geom_pointrange(aes(ymin = lnRR_lwr, ymax = lnRR_upr), size = 0.6, linewidth = 0.8) +
  scale_colour_manual(values = col.v[c(1, 3)]) +
  ylab("lnRSR") +
  ggtitle("(a)") +
  coord_cartesian(ylim = c(rsr_mn.n,
                           rsr_mx.n)) +
  theme(panel.background = element_blank(),
        panel.grid = element_blank(),
        axis.line = element_line(),
        axis.text = element_text(colour = "black", size = 10),
        axis.title.x = element_blank(),
        axis.title.y = element_text(size = 10),
        plot.title = element_text(size = 10, face = "bold", hjust = 0),
        plot.subtitle = element_text(size = 10, hjust = 0.5, vjust = 0),
        legend.text = element_text(size = 10),
        legend.title = element_blank(),
        legend.position = c(1, 1),
        legend.justification = c("left", "top"),
        legend.background = element_blank(),
        legend.key = element_blank())

## Forest plantations
### (b) Main
f3b1 <- ggplot(data = rsr_f_m.df, aes(y = lnRR_pred, x = Level, col = Natural_elements, fill = Natural_elements)) +
  geom_hline(yintercept = 0, linetype = "dashed") +
  geom_pointrange(aes(ymin = lnRR_lwr, ymax = lnRR_upr), size = 0.6, linewidth = 0.8) +
  scale_colour_manual(values = col.v[c(1, 3)]) +
  ylab("lnRSR") +
  ggtitle("(b)") +
  coord_cartesian(ylim = c(rsr_mn.n,
                           rsr_mx.n)) +
  theme(panel.background = element_blank(),
        panel.grid = element_blank(),
        axis.line = element_line(),
        axis.text = element_text(colour = "black", size = 10),
        axis.title.x = element_blank(),
        axis.title.y = element_text(size = 10),
        plot.title = element_text(size = 10, face = "bold", hjust = 0),
        plot.subtitle = element_text(size = 10, hjust = 0.5, vjust = 0),
        legend.text = element_text(size = 10),
        legend.title = element_blank(),
        legend.position = "none",
        legend.justification = c("left", "top"),
        legend.background = element_blank(),
        legend.key = element_blank())

### (c) Latitude
f3b2 <- ggplot(data = rsr_f_l.df, aes(y = lnRR_pred, x = Latitude_abs, col = Natural_elements, fill = Natural_elements)) +
  geom_hline(yintercept = 0, linetype = "dashed") +
  geom_line(linewidth = 1.5) +
  geom_ribbon(aes(ymin = lnRR_lwr, ymax = lnRR_upr), alpha = 0.2, col = NA) +
  scale_colour_manual(values = col.v[c(1, 3)]) +
  scale_fill_manual(values = col.v[c(1, 3)]) +
  ylab("lnRSR") +
  xlab("Absolute latitude") +
  #ggtitle("(c)") +
  coord_cartesian(ylim = c(rsr_mn.n, rsr_mx.n)) +
  theme(panel.background = element_blank(),
        panel.grid = element_blank(),
        axis.line = element_line(),
        axis.text = element_text(colour = "black", size = 10),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.title.x = element_text(size = 10),
        plot.title = element_text(size = 10, face = "bold", hjust = 0),
        legend.text = element_text(size = 10),
        legend.title = element_blank(),
        legend.position = "none",
        legend.direction = "vertical",
        legend.justification = c("left", "top"),
        legend.background = element_blank(),
        legend.key = element_blank())

## Panels
ggarrange(f3a, ggplot() + theme_void(), f3b1, f3b2, ncol = 2)

# Fig4 MSA ----------------------------------------------------------------

# Data preparation
## Cropland
msa_c.df <- filter(msa.df, Land_use == "Cropland")
msa_c.df <- group_by(msa_c.df, Natural_elements)
msa_c.df <- mutate(msa_c.df, n = n(), Level = paste0("n = ", n()))
msa_c.df <- ungroup(msa_c.df)
msa_c.df <- mutate(msa_c.df, Natural_elements = as_factor(str_replace_all(Natural_elements, "_", " ")))

### Main
msa_cm.lm <- lmer(ltMSA ~ Natural_elements + (1|Source_ID / Study_ID), weights = weight, data = msa_c.df, REML = T)
msa_cm.df <- distinct(select(msa_c.df, Natural_elements, Level))
b.bm <- bootMer(msa_cm.lm, nsim = 1000, FUN = function(x){predict(x, newdata = msa_cm.df, re.form = NA)})
msa_cm.df <- mutate(msa_cm.df, lnRR_pred = predict(msa_cm.lm, newdata = msa_cm.df, re.form = NA),
                    lnRR_lwr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.025)}),
                    lnRR_upr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.975)}))
msa_cm.df <- mutate(msa_cm.df, MSA_pred = exp(lnRR_pred) / (1 + exp(lnRR_pred)),
                    MSA_lwr = exp(lnRR_lwr) / (1 + exp(lnRR_lwr)),
                    MSA_upr = exp(lnRR_upr) / (1 + exp(lnRR_upr)))

### Latitude
msa_cl.lm <- lmer(ltMSA ~ Natural_elements + Latitude_abs + Latitude2_abs + (1|Source_ID / Study_ID), weights = weight, data = msa_c.df, REML = T)
msa_cl.df <- distinct(select(msa_c.df, Natural_elements, Level))
msa_cl.df <- msa_cl.df[rep(1:nrow(msa_cl.df), each = seq.n), ]
msa_cl.df <- mutate(msa_cl.df, Latitude_abs = c(seq(min(pull(filter(msa_c.df, Natural_elements == unique(pull(msa_cl.df, Natural_elements))[1]), Latitude_abs)),
                                                    max(pull(filter(msa_c.df, Natural_elements == unique(pull(msa_cl.df, Natural_elements))[1]), Latitude_abs)),
                                                    (max(pull(filter(msa_c.df, Natural_elements == unique(pull(msa_cl.df, Natural_elements))[1]), Latitude_abs)) -
                                                       min(pull(filter(msa_c.df, Natural_elements == unique(pull(msa_cl.df, Natural_elements))[1]), Latitude_abs))) /
                                                      (seq.n - 1)),
                                                seq(min(pull(filter(msa_c.df, Natural_elements == unique(pull(msa_cl.df, Natural_elements))[2]), Latitude_abs)),
                                                    max(pull(filter(msa_c.df, Natural_elements == unique(pull(msa_cl.df, Natural_elements))[2]), Latitude_abs)),
                                                    (max(pull(filter(msa_c.df, Natural_elements == unique(pull(msa_cl.df, Natural_elements))[2]), Latitude_abs)) -
                                                       min(pull(filter(msa_c.df, Natural_elements == unique(pull(msa_cl.df, Natural_elements))[2]), Latitude_abs))) /
                                                      (seq.n - 1))
))
msa_cl.df <- mutate(msa_cl.df, Latitude2_abs = Latitude_abs^2)
b.bm <- bootMer(msa_cl.lm, nsim = 1000, FUN = function(x){predict(x, newdata = msa_cl.df, re.form = NA)})
msa_cl.df <- mutate(msa_cl.df, lnRR_pred = predict(msa_cl.lm, newdata = msa_cl.df, re.form = NA),
                    lnRR_lwr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.025)}),
                    lnRR_upr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.975)}))
msa_cl.df <- mutate(msa_cl.df, MSA_pred = exp(lnRR_pred) / (1 + exp(lnRR_pred)),
                    MSA_lwr = exp(lnRR_lwr) / (1 + exp(lnRR_lwr)),
                    MSA_upr = exp(lnRR_upr) / (1 + exp(lnRR_upr)))

## Forest plantations
msa_f.df <- filter(msa.df, Land_use == "Forest_plantation")
msa_f.df <- group_by(msa_f.df, Diversification)
msa_f.df <- mutate(msa_f.df, n = n(), Level = paste0("n = ", n()))
msa_f.df <- ungroup(msa_f.df)
msa_f.df <- mutate(msa_f.df, Diversification = as_factor(str_replace_all(Diversification, "_", " ")))
msa_f.df <- mutate(msa_f.df, Diversification = fct_relevel(Diversification, levels(pull(msa_f.df, Diversification))[2]))

### Main
msa_fm.lm <- lmer(ltMSA ~ Diversification + (1|Source_ID / Study_ID), weights = weight, data = msa_f.df, REML = T)
msa_fm.df <- distinct(select(msa_f.df, Diversification, Level))
b.bm <- bootMer(msa_fm.lm, nsim = 1000, FUN = function(x){predict(x, newdata = msa_fm.df, re.form = NA)})
msa_fm.df <- mutate(msa_fm.df, lnRR_pred = predict(msa_fm.lm, newdata = msa_fm.df, re.form = NA),
                    lnRR_lwr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.025)}),
                    lnRR_upr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.975)}))
msa_fm.df <- mutate(msa_fm.df, MSA_pred = exp(lnRR_pred) / (1 + exp(lnRR_pred)),
                    MSA_lwr = exp(lnRR_lwr) / (1 + exp(lnRR_lwr)),
                    MSA_upr = exp(lnRR_upr) / (1 + exp(lnRR_upr)))

### Landsape context
msa_flc.lm <- lmer(ltMSA ~ Diversification + Landscape_context + (1|Source_ID / Study_ID), weights = weight, data = msa_f.df, REML = T)
msa_flc.df <- distinct(select(msa_f.df, Diversification, Level))
msa_flc.df <- msa_flc.df[rep(1:nrow(msa_flc.df), each = seq.n), ]
msa_flc.df <- mutate(msa_flc.df, Landscape_context = c(seq(min(pull(filter(msa_f.df, Diversification == unique(pull(msa_flc.df, Diversification))[1]), Landscape_context)),
                                                           max(pull(filter(msa_f.df, Diversification == unique(pull(msa_flc.df, Diversification))[1]), Landscape_context)),
                                                           (max(pull(filter(msa_f.df, Diversification == unique(pull(msa_flc.df, Diversification))[1]), Landscape_context)) -
                                                              min(pull(filter(msa_f.df, Diversification == unique(pull(msa_flc.df, Diversification))[1]), Landscape_context))) /
                                                             (seq.n - 1)),
                                                       seq(min(pull(filter(msa_f.df, Diversification == unique(pull(msa_flc.df, Diversification))[2]), Landscape_context)),
                                                           max(pull(filter(msa_f.df, Diversification == unique(pull(msa_flc.df, Diversification))[2]), Landscape_context)),
                                                           (max(pull(filter(msa_f.df, Diversification == unique(pull(msa_flc.df, Diversification))[2]), Landscape_context)) -
                                                              min(pull(filter(msa_f.df, Diversification == unique(pull(msa_flc.df, Diversification))[2]), Landscape_context))) /
                                                             (seq.n - 1))
))
b.bm <- bootMer(msa_flc.lm, nsim = 1000, FUN = function(x){predict(x, newdata = msa_flc.df, re.form = NA)})
msa_flc.df <- mutate(msa_flc.df, lnRR_pred = predict(msa_flc.lm, newdata = msa_flc.df, re.form = NA),
                     lnRR_lwr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.025)}),
                     lnRR_upr = apply(b.bm$t, 2, FUN = function(x){quantile(x, 0.975)}))
msa_flc.df <- mutate(msa_flc.df, MSA_pred = exp(lnRR_pred) / (1 + exp(lnRR_pred)),
                     MSA_lwr = exp(lnRR_lwr) / (1 + exp(lnRR_lwr)),
                     MSA_upr = exp(lnRR_upr) / (1 + exp(lnRR_upr)))

# Figures
## Cropland
### (a) Main
f4a1 <- ggplot(data = msa_cm.df, aes(y = MSA_pred, x = Level, col = Natural_elements, fill = Natural_elements)) +
  geom_hline(yintercept = 1, linetype = "dashed") +
  geom_pointrange(aes(ymin = MSA_lwr, ymax = MSA_upr), size = 0.6, linewidth = 0.8) +
  scale_colour_manual(values = col.v[c(1, 3)]) +
  ylab("MSA") +
  ggtitle("(a)") +
  coord_cartesian(ylim = c(0, 1)) +
  theme(panel.background = element_blank(),
        panel.grid = element_blank(),
        axis.line = element_line(),
        axis.text = element_text(colour = "black", size = 10),
        axis.title.y = element_text(size = 10),
        axis.title.x = element_blank(),
        plot.title = element_text(size = 10, face = "bold", hjust = 0),
        plot.subtitle = element_text(size = 10, hjust = 0.5, vjust = 0),
        legend.text = element_text(colour = "black", size = 10),
        legend.title = element_blank(),
        legend.position = c(0, 0.35),
        legend.justification = c("left", "top"),
        legend.background = element_blank(),
        legend.key = element_blank())

### (b) Latitude
f4a2 <- ggplot(data = msa_cl.df, aes(y = MSA_pred, x = Latitude_abs, col = Natural_elements, fill = Natural_elements)) +
  geom_hline(yintercept = 1, linetype = "dashed") +
  geom_line(linewidth = 1.5) +
  geom_ribbon(aes(ymin = MSA_lwr, ymax = MSA_upr), alpha = 0.2, col = NA) +
  #scale_x_continuous(breaks = seq(1, max(ria_c.df$Habitat_breadth, na.rm = T), 2)) +
  scale_colour_manual(values = col.v[c(1, 3)]) +
  scale_fill_manual(values = col.v[c(1, 3)]) +
  ylab("MSA") +
  xlab("Absolute latitude") +
  #ggtitle("(b)") +
  coord_cartesian(ylim = c(0, 1)) +
  theme(panel.background = element_blank(),
        panel.grid = element_blank(),
        axis.line = element_line(),
        axis.text = element_text(colour = "black", size = 10),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.title.x = element_text(size = 10),
        plot.title = element_text(size = 10, face = "bold", hjust = 0),
        legend.text = element_text(colour = "black", size = 10),
        legend.title = element_blank(),
        legend.position = "none",
        legend.direction = "vertical",
        legend.justification = c("left", "top"),
        legend.background = element_blank(),
        legend.key = element_blank())

## Forest plantation
### (c) Main
f4b1 <- ggplot(data = msa_fm.df, aes(y = MSA_pred, x = Level, col = Diversification, fill = Diversification)) +
  geom_hline(yintercept = 1, linetype = "dashed") +
  geom_pointrange(aes(ymin = MSA_lwr, ymax = MSA_upr), size = 0.6, linewidth = 0.8) +
  scale_colour_manual(values = col.v[c(2, 4)]) +
  ylab("MSA") +
  ggtitle("(b)") +
  coord_cartesian(ylim = c(0, 1)) +
  theme(panel.background = element_blank(),
        panel.grid = element_blank(),
        axis.line = element_line(),
        axis.text = element_text(colour = "black", size = 10),
        axis.title.y = element_text(size = 10),
        axis.title.x = element_blank(),
        plot.title = element_text(size = 10, face = "bold", hjust = 0),
        plot.subtitle = element_text(size = 10, hjust = 0.5, vjust = 0),
        legend.text = element_text(colour = "black", size = 10),
        legend.title = element_blank(),
        legend.position = c(0, 0.35),
        legend.justification = c("left", "top"),
        legend.background = element_blank(),
        legend.key = element_blank())

### (d) Landscape context
f4b2 <- ggplot(data = msa_flc.df, aes(y = MSA_pred, x = Landscape_context, col = Diversification, fill = Diversification)) +
  geom_hline(yintercept = 1, linetype = "dashed") +
  geom_line(linewidth = 1.5) +
  geom_ribbon(aes(ymin = MSA_lwr, ymax = MSA_upr), alpha = 0.2, col = NA) +
  #scale_x_continuous(breaks = seq(1, max(ria_c.df$Habitat_breadth, na.rm = T), 2)) +
  scale_colour_manual(values = col.v[c(2, 4)]) +
  scale_fill_manual(values = col.v[c(2, 4)]) +
  ylab("MSA") +
  xlab("Share of (semi-)natural\nlandcover") +
  #ggtitle("(d)") +
  coord_cartesian(ylim = c(0, 1)) +
  theme(panel.background = element_blank(),
        panel.grid = element_blank(),
        axis.line = element_line(),
        axis.text = element_text(colour = "black", size = 10),
        axis.text.x = element_text(size = 10),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.title.x = element_text(size = 10),
        plot.title = element_text(size = 10, face = "bold", hjust = 0),
        legend.text = element_text(colour = "black", size = 10),
        legend.title = element_blank(),
        legend.position = "none",
        legend.direction = "vertical",
        legend.justification = c("left", "top"),
        legend.background = element_blank(),
        legend.key = element_blank())

## Panels
ggarrange(f4a1, f4a2, f4b1, f4b2, ncol = 2)


# FigS2 -------------------------------------------------------------------

# prepare data
## abundance
### cropland
ria_c.df <- filter(ria.df, Land_use == "Cropland")
ria_c.df <- arrange(ria_c.df, lnRR)
ria_c.df <- mutate(ria_c.df, Order_ID = 1:nrow(ria_c.df))

### forest plantation
ria_f.df <- filter(ria.df, Land_use == "Forest_plantation")
ria_f.df <- arrange(ria_f.df, lnRR)
ria_f.df <- mutate(ria_f.df, Order_ID = 1:nrow(ria_f.df))

## richness
### cropland
rsr_c.df <- filter(sr.df, Land_use == "Cropland")
rsr_c.df <- arrange(rsr_c.df, lnRR)
rsr_c.df <- mutate(rsr_c.df, Order_ID = 1:nrow(rsr_c.df))

### forest plantation
rsr_f.df <- filter(sr.df, Land_use == "Forest_plantation")
rsr_f.df <- arrange(rsr_f.df, lnRR)
rsr_f.df <- mutate(rsr_f.df, Order_ID = 1:nrow(rsr_f.df))

## MSA
### cropland
msa_c.df <- filter(msa.df, Land_use == "Cropland")
msa_c.df <- arrange(msa_c.df, ltMSA)
msa_c.df <- mutate(msa_c.df, Order_ID = 1:nrow(msa_c.df))

### forest plantation
msa_f.df <- filter(msa.df, Land_use == "Forest_plantation")
msa_f.df <- arrange(msa_f.df, ltMSA)
msa_f.df <- mutate(msa_f.df, Order_ID = 1:nrow(msa_f.df))

# Figures
## abundance
### cropland
fs2a <- ggplot(data = ria_c.df, aes(x = lnRR, y = Order_ID)) +
  geom_ribbon(aes(xmin = mean(lnRR) - qt(0.975, nrow(ria_c.df) - 1) - (sd(lnRR) / sqrt(nrow(ria_c.df))),
                  xmax = mean(lnRR) + qt(0.975, nrow(ria_c.df) - 1) - (sd(lnRR) / sqrt(nrow(ria_c.df)))),
              fill = "lightgrey") +
  geom_vline(xintercept = 0, colour = "black", linetype = "dashed") +
  geom_vline(xintercept = mean(pull(ria_c.df, lnRR)), colour = "darkgrey", linewidth = 0.8) +
  geom_point() +
  scale_y_continuous(expand = c(0, 0)) +
  ggtitle("Cropland") +
  xlab("lnRIA") +
  ylab("Individual species\nabundance") +
  theme(panel.background = element_blank(),
        text = element_text(colour = "black", size = 10),
        axis.text.x = element_text(colour = "black", size = 10),
        axis.line.x = element_line(),
        axis.ticks.y = element_blank(),
        axis.text.y = element_blank(),
        axis.title = element_text(colour = "black", size = 10),
        plot.title = element_text(colour = "black", size = 10, hjust = 0.5))

### forest plantation
fs2b <- ggplot(data = ria_f.df, aes(x = lnRR, y = Order_ID)) +
  geom_ribbon(aes(xmin = mean(lnRR) - qt(0.975, nrow(ria_f.df) - 1) - (sd(lnRR) / sqrt(nrow(ria_f.df))),
                  xmax = mean(lnRR) + qt(0.975, nrow(ria_f.df) - 1) - (sd(lnRR) / sqrt(nrow(ria_f.df)))),
              fill = "lightgrey") +
  geom_vline(xintercept = 0, colour = "black", linetype = "dashed") +
  geom_vline(xintercept = mean(pull(ria_f.df, lnRR)), colour = "darkgrey", linewidth = 0.8) +
  geom_point() +
  scale_y_continuous(expand = c(0, 0)) +
  ggtitle("Forest plantation") +
  xlab("lnRIA") +
  #ylab("Individual species abundance") +
  theme(panel.background = element_blank(),
        text = element_text(colour = "black", size = 10),
        axis.text.x = element_text(colour = "black", size = 10),
        axis.line.x = element_line(),
        axis.ticks.y = element_blank(),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.title = element_text(colour = "black", size = 10),
        plot.title = element_text(colour = "black", size = 10, hjust = 0.5))

## species richness
### cropland
fs2c <- ggplot(data = rsr_c.df, aes(x = lnRR, y = Order_ID)) +
  geom_ribbon(aes(xmin = mean(lnRR) - qt(0.975, nrow(rsr_c.df) - 1) - (sd(lnRR) / sqrt(nrow(rsr_c.df))),
                  xmax = mean(lnRR) + qt(0.975, nrow(rsr_c.df) - 1) - (sd(lnRR) / sqrt(nrow(rsr_c.df)))),
              fill = "lightgrey") +
  geom_vline(xintercept = 0, colour = "black", linetype = "dashed") +
  geom_vline(xintercept = mean(pull(rsr_c.df, lnRR)), colour = "darkgrey", linewidth = 0.8) +
  geom_point() +
  scale_y_continuous(expand = c(0, 0)) +
  #ggtitle("Cropland") +
  xlab("lnRSR") +
  ylab("Species\nrichness") +
  theme(panel.background = element_blank(),
        text = element_text(colour = "black", size = 10),
        axis.text.x = element_text(colour = "black", size = 10),
        axis.line.x = element_line(),
        axis.ticks.y = element_blank(),
        axis.text.y = element_blank(),
        axis.title = element_text(colour = "black", size = 10),
        plot.title = element_text(colour = "black", size = 10, hjust = 0.5))

### forest plantation
fs2d <- ggplot(data = rsr_f.df, aes(x = lnRR, y = Order_ID)) +
  geom_ribbon(aes(xmin = mean(lnRR) - qt(0.975, nrow(rsr_f.df) - 1) - (sd(lnRR) / sqrt(nrow(rsr_f.df))),
                  xmax = mean(lnRR) + qt(0.975, nrow(rsr_f.df) - 1) - (sd(lnRR) / sqrt(nrow(rsr_f.df)))),
              fill = "lightgrey") +
  geom_vline(xintercept = 0, colour = "black", linetype = "dashed") +
  geom_vline(xintercept = mean(pull(rsr_f.df, lnRR)), colour = "darkgrey", linewidth = 0.8) +
  geom_point() +
  scale_y_continuous(expand = c(0, 0)) +
  #ggtitle("Forest plantation") +
  xlab("lnRSR") +
  #ylab("Individual species abundance") +
  theme(panel.background = element_blank(),
        text = element_text(colour = "black", size = 10),
        axis.text.x = element_text(colour = "black", size = 10),
        axis.line.x = element_line(),
        axis.ticks.y = element_blank(),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.title = element_text(colour = "black", size = 10),
        plot.title = element_text(colour = "black", size = 10, hjust = 0.5))

## MSA
### cropland
fs2e <- ggplot(data = msa_c.df, aes(x = ltMSA, y = Order_ID)) +
  geom_ribbon(aes(xmin = mean(ltMSA) - qt(0.975, nrow(msa_c.df) - 1) - (sd(ltMSA) / sqrt(nrow(msa_c.df))),
                  xmax = mean(ltMSA) + qt(0.975, nrow(msa_c.df) - 1) - (sd(ltMSA) / sqrt(nrow(msa_c.df)))),
              fill = "lightgrey") +
  #geom_vline(xintercept = 0, colour = "black", linetype = "dashed") +
  geom_vline(xintercept = mean(pull(msa_c.df, ltMSA)), colour = "darkgrey", linewidth = 0.8) +
  geom_point() +
  scale_y_continuous(expand = c(0, 0)) +
  #ggtitle("Forest plantation") +
  xlab("logitMSA") +
  ylab("Assemblage\nintactness") +
  theme(panel.background = element_blank(),
        text = element_text(colour = "black", size = 10),
        axis.text.x = element_text(colour = "black", size = 10),
        axis.line.x = element_line(),
        axis.ticks.y = element_blank(),
        axis.text.y = element_blank(),
        #axis.title.y = element_blank(),
        axis.title = element_text(colour = "black", size = 10),
        plot.title = element_text(colour = "black", size = 10, hjust = 0.5))

### forest plantation
fs2f <- ggplot(data = msa_f.df, aes(x = ltMSA, y = Order_ID)) +
  geom_ribbon(aes(xmin = mean(ltMSA) - qt(0.975, nrow(msa_f.df) - 1) - (sd(ltMSA) / sqrt(nrow(msa_f.df))),
                  xmax = mean(ltMSA) + qt(0.975, nrow(msa_f.df) - 1) - (sd(ltMSA) / sqrt(nrow(msa_f.df)))),
              fill = "lightgrey") +
  #geom_vline(xintercept = 0, colour = "black", linetype = "dashed") +
  geom_vline(xintercept = mean(pull(msa_f.df, ltMSA)), colour = "darkgrey", linewidth = 0.8) +
  geom_point() +
  scale_y_continuous(expand = c(0, 0)) +
  #ggtitle("Forest plantation") +
  xlab("logitMSA") +
  #ylab("Assemblage intactness") +
  theme(panel.background = element_blank(),
        text = element_text(colour = "black", size = 10),
        axis.text.x = element_text(colour = "black", size = 10),
        axis.line.x = element_line(),
        axis.ticks.y = element_blank(),
        axis.text.y = element_blank(),
        axis.title.y = element_blank(),
        axis.title = element_text(colour = "black", size = 10),
        plot.title = element_text(colour = "black", size = 10, hjust = 0.5))

# Panels
ggarrange(fs2a, fs2b, fs2c, fs2d, fs2e, fs2f, ncol = 2)
